
# Slot: quantifier qualifier


A measurable quantity for the object of the association

URI: [biolink:quantifier_qualifier](https://w3id.org/biolink/vocab/quantifier_qualifier)


## Domain and Range

[Association](Association.md) &#8594;  <sub>0..1</sub> [OntologyClass](OntologyClass.md)

## Parents

 *  is_a: [association slot](association_slot.md)

## Children

 *  [gene expression mixin➞quantifier qualifier](gene_expression_mixin_quantifier_qualifier.md)
 *  [gene to expression site association➞quantifier qualifier](gene_to_expression_site_association_quantifier_qualifier.md)

## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **Narrow Mappings:** | | LOINC:analyzes |
|  | | LOINC:measured_by |
|  | | LOINC:property_of |
|  | | SEMMEDDB:measures |
|  | | UMLS:measures |

